Method: RGD::Image#string_up

Defined in:
ext/rgd/rgd.c

#string_up(font, x, y, str, color) ⇒ Object

Used to draw multiple characters on the image, rotated 90 degrees. (To draw single characters, use Image.char_up.)

The argument str is drawn from bottom to top (rotated 90 degrees) in the specified color. (See Image.string for a way of drawing horizontal text.) Pixels not set by a particular character retain their previous color.



2268
2269
2270
# File 'ext/rgd/rgd.c', line 2268

static VALUE image_string_up(VALUE klass, VALUE font, VALUE x, VALUE y, VALUE str, VALUE color) {
    return gd_image_string(klass, font, x, y, str, color, gdImageStringUp);
}